@@@@@@@
Credits
@@@@@@@

.. |dob| replace:: ``dob``
.. _dob: https://github.com/hotoffthehamster/dob

.. |dob-prompt| replace:: ``dob-prompt``
.. _dob-prompt: https://github.com/hotoffthehamster/dob-prompt

.. |dob-viewer| replace:: ``dob-viewer``
.. _dob-viewer: https://github.com/hotoffthehamster/dob-viewer

.. |nark| replace:: ``nark``
.. _nark: https://github.com/hotoffthehamster/nark

###############################
``dob-viewer`` (2018 — Present)
###############################

Project Lead
============

..  (`Landon Bouma <https://github.com/landonb>`_)

* `HotOffThe Hamster <https://github.com/hotoffthehamster>`_
  (aka Landon Bouma ``<hotoffthehamster+landonb -at- gmail.com>``)

